@@ -6,8 +6,8 @@ import (
 	"os"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/logext"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/logext"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 )
 
 func loadConfig(path string) (config.Project, error) {
@@ -27,7 +27,9 @@ func loadConfigCheck(path string) (config.Project, string, error) {
 		p, err := config.Load(path)
 		return p, path, err
 	}
-	for _, f := range [4]string{
+	for _, f := range [6]string{
+		".config/goreleaser.yml",
+		".config/goreleaser.yaml",
 		".goreleaser.yml",
 		".goreleaser.yaml",
 		"goreleaser.yml",
