@@ -8,7 +8,7 @@ import (
 	goversion "github.com/caarlos0/go-version"
 	"github.com/caarlos0/log"
 	"github.com/charmbracelet/lipgloss"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/spf13/cobra"
 )
 
@@ -28,6 +28,10 @@ func (cmd *rootCmd) Execute(args []string) {
 		cmd.cmd.SetArgs(append([]string{"release"}, args...))
 	}
 
+	if shouldDisableLogs(args) {
+		log.SetLevel(log.FatalLevel)
+	}
+
 	if err := cmd.cmd.Execute(); err != nil {
 		code := 1
 		msg := "command failed"
@@ -47,9 +51,6 @@ type rootCmd struct {
 	cmd     *cobra.Command
 	verbose bool
 	exit    func(int)
-
-	// Deprecated: use verbose instead.
-	debug bool
 }
 
 func newRootCmd(version goversion.Info, exit func(int)) *rootCmd {
@@ -73,22 +74,19 @@ Check out our website for more information, examples and documentation: https://
 		SilenceErrors:     true,
 		Args:              cobra.NoArgs,
 		ValidArgsFunction: cobra.NoFileCompletions,
-		PersistentPreRun: func(_ *cobra.Command, _ []string) {
-			if root.verbose || root.debug {
+		PersistentPreRun: func(*cobra.Command, []string) {
+			if root.verbose {
 				log.SetLevel(log.DebugLevel)
 				log.Debug("verbose output enabled")
 			}
 		},
-		PersistentPostRun: func(_ *cobra.Command, _ []string) {
+		PersistentPostRun: func(*cobra.Command, []string) {
 			log.Info("thanks for using goreleaser!")
 		},
 	}
 	cmd.SetVersionTemplate("{{.Version}}")
 
-	cmd.PersistentFlags().BoolVar(&root.debug, "debug", false, "Enable verbose mode")
 	cmd.PersistentFlags().BoolVar(&root.verbose, "verbose", false, "Enable verbose mode")
-	_ = cmd.Flags().MarkDeprecated("debug", "please use --verbose instead")
-	_ = cmd.Flags().MarkHidden("debug")
 	cmd.AddCommand(
 		newBuildCmd().cmd,
 		newReleaseCmd().cmd,
@@ -103,6 +101,16 @@ Check out our website for more information, examples and documentation: https://
 	return root
 }
 
+func shouldDisableLogs(args []string) bool {
+	return len(args) > 0 && (args[0] == "help" ||
+		args[0] == "completion" ||
+		args[0] == "man" ||
+		args[0] == "docs" ||
+		args[0] == "jsonschema" ||
+		args[0] == cobra.ShellCompRequestCmd ||
+		args[0] == cobra.ShellCompNoDescRequestCmd)
+}
+
 func shouldPrependRelease(cmd *cobra.Command, args []string) bool {
 	// find current cmd, if its not root, it means the user actively
 	// set a command, so let it go
