@@ -13,21 +13,22 @@ import (
 
 	"dario.cat/mergo"
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/builders/buildtarget"
-	"github.com/goreleaser/goreleaser/internal/gio"
-	"github.com/goreleaser/goreleaser/internal/logext"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	api "github.com/goreleaser/goreleaser/pkg/build"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/builders/buildtarget"
+	"github.com/goreleaser/goreleaser/v2/internal/gio"
+	"github.com/goreleaser/goreleaser/v2/internal/logext"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	api "github.com/goreleaser/goreleaser/v2/pkg/build"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 // Default builder instance.
-// nolint: gochecknoglobals
+//
+//nolint:gochecknoglobals
 var Default = &Builder{}
 
-// nolint: gochecknoinits
+//nolint:gochecknoinits
 func init() {
 	api.Register("go", Default)
 }
@@ -372,7 +373,6 @@ func processFlag(ctx *context.Context, a *artifact.Artifact, env []string, rawFl
 func run(ctx *context.Context, command, env []string, dir string) error {
 	/* #nosec */
 	cmd := exec.CommandContext(ctx, command[0], command[1:]...)
-	log := log.WithField("env", env).WithField("cmd", command)
 	cmd.Env = env
 	cmd.Dir = dir
 	log.Debug("running")
@@ -380,12 +380,23 @@ func run(ctx *context.Context, command, env []string, dir string) error {
 	if err != nil {
 		return fmt.Errorf("%w: %s", err, string(out))
 	}
-	if s := strings.TrimSpace(string(out)); s != "" {
-		log.Info(s)
+	if s := buildOutput(out); s != "" {
+		log.WithField("cmd", command).Info(s)
 	}
 	return nil
 }
 
+func buildOutput(out []byte) string {
+	var lines []string
+	for _, line := range strings.Split(strings.TrimSpace(string(out)), "\n") {
+		if strings.HasPrefix(line, "go: downloading") {
+			continue
+		}
+		lines = append(lines, line)
+	}
+	return strings.Join(lines, "\n")
+}
+
 func checkMain(build config.Build) error {
 	if build.NoMainCheck {
 		return nil
