@@ -11,11 +11,10 @@ import (
 	"strings"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/deprecate"
-	"github.com/goreleaser/goreleaser/internal/git"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/git"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 // ErrInvalidSortDirection happens when the sort order is invalid.
@@ -46,10 +45,6 @@ func (Pipe) Skip(ctx *context.Context) (bool, error) {
 	if ctx.Snapshot {
 		return true, nil
 	}
-	if ctx.Config.Changelog.Skip != "" {
-		deprecate.Notice(ctx, "changelog.skip")
-		ctx.Config.Changelog.Disable = ctx.Config.Changelog.Skip
-	}
 
 	return tmpl.New(ctx).Bool(ctx.Config.Changelog.Disable)
 }
