@@ -11,11 +11,11 @@ import (
 
 	"github.com/caarlos0/log"
 	"github.com/charmbracelet/x/exp/ordered"
-	"github.com/goreleaser/goreleaser/internal/git"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/git"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 // Pipe that sets up git state.
@@ -54,7 +54,7 @@ func (Pipe) Run(ctx *context.Context) error {
 	return validate(ctx)
 }
 
-// nolint: gochecknoglobals
+//nolint:gochecknoglobals
 var fakeInfo = context.GitInfo{
 	Branch:      "none",
 	CurrentTag:  "v0.0.0",
