@@ -8,33 +8,35 @@ import (
 	"time"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/gio"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/gio"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
-// Pipe implementation.
-type Pipe struct{}
+type (
+	// Pipe implementation.
+	Pipe struct{}
+	// MetaPipe implementation.
+	MetaPipe struct{}
+	// ArtifactsPipe implementation.
+	ArtifactsPipe struct{}
+)
 
-func (Pipe) String() string               { return "storing release metadata" }
-func (Pipe) Skip(_ *context.Context) bool { return false }
-
-// Run the pipe.
+func (Pipe) String() string { return "setting up metadata" }
 func (Pipe) Run(ctx *context.Context) error {
-	if err := tmpl.New(ctx).ApplyAll(
-		&ctx.Config.Metadata.ModTimestamp,
-	); err != nil {
-		return err
-	}
-	if err := writeArtifacts(ctx); err != nil {
-		return err
-	}
-	return writeMetadata(ctx)
+	return tmpl.New(ctx).ApplyAll(&ctx.Config.Metadata.ModTimestamp)
 }
 
+func (MetaPipe) String() string                 { return "storing release metadata" }
+func (MetaPipe) Run(ctx *context.Context) error { return writeMetadata(ctx) }
+
+func (ArtifactsPipe) String() string                 { return "storing artifacts metadata" }
+func (ArtifactsPipe) Run(ctx *context.Context) error { return writeArtifacts(ctx) }
+
 func writeMetadata(ctx *context.Context) error {
-	return writeJSON(ctx, metadata{
+	const name = "metadata.json"
+	path, err := writeJSON(ctx, metadata{
 		ProjectName: ctx.Config.ProjectName,
 		Tag:         ctx.Git.CurrentTag,
 		PreviousTag: ctx.Git.PreviousTag,
@@ -45,7 +47,13 @@ func writeMetadata(ctx *context.Context) error {
 			Goos:   ctx.Runtime.Goos,
 			Goarch: ctx.Runtime.Goarch,
 		},
-	}, "metadata.json")
+	}, name)
+	ctx.Artifacts.Add(&artifact.Artifact{
+		Name: name,
+		Path: path,
+		Type: artifact.Metadata,
+	})
+	return err
 }
 
 func writeArtifacts(ctx *context.Context) error {
@@ -54,21 +62,22 @@ func writeArtifacts(ctx *context.Context) error {
 		a.Path = filepath.ToSlash(filepath.Clean(a.Path))
 		return nil
 	})
-	return writeJSON(ctx, ctx.Artifacts.List(), "artifacts.json")
+	_, err := writeJSON(ctx, ctx.Artifacts.List(), "artifacts.json")
+	return err
 }
 
-func writeJSON(ctx *context.Context, j interface{}, name string) error {
+func writeJSON(ctx *context.Context, j interface{}, name string) (string, error) {
 	bts, err := json.Marshal(j)
 	if err != nil {
-		return err
+		return "", err
 	}
 	path := filepath.Join(ctx.Config.Dist, name)
 	log.Log.WithField("file", path).Info("writing")
 	if err := os.WriteFile(path, bts, 0o644); err != nil {
-		return err
+		return "", err
 	}
 
-	return gio.Chtimes(path, ctx.Config.Metadata.ModTimestamp)
+	return path, gio.Chtimes(path, ctx.Config.Metadata.ModTimestamp)
 }
 
 type metadata struct {
