@@ -1,6 +1,6 @@
 // Package snapcraft implements the Pipe interface providing Snapcraft bindings.
 //
-// nolint:tagliatelle
+//nolint:tagliatelle
 package snapcraft
 
 import (
@@ -12,16 +12,16 @@ import (
 	"strings"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/gio"
-	"github.com/goreleaser/goreleaser/internal/ids"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/semerrgroup"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/internal/yaml"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/gio"
+	"github.com/goreleaser/goreleaser/v2/internal/ids"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/semerrgroup"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/internal/yaml"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 const releasesExtra = "releases"
@@ -193,7 +193,6 @@ func doRun(ctx *context.Context, snap config.Snapcraft) error {
 			log.WithField("arch", arch).Warn("ignored unsupported arch")
 			continue
 		}
-		binaries := binaries
 		g.Go(func() error {
 			return create(ctx, snap, arch, binaries)
 		})
@@ -454,7 +453,7 @@ func push(ctx *context.Context, snap *artifact.Artifact) error {
 }
 
 func processChannelsTemplates(ctx *context.Context, snap config.Snapcraft) ([]string, error) {
-	// nolint:prealloc
+	//nolint:prealloc
 	var channels []string
 	for _, channeltemplate := range snap.ChannelTemplates {
 		channel, err := tmpl.New(ctx).Apply(channeltemplate)
