@@ -4,42 +4,42 @@ package pipeline
 import (
 	"fmt"
 
-	"github.com/goreleaser/goreleaser/internal/pipe/announce"
-	"github.com/goreleaser/goreleaser/internal/pipe/archive"
-	"github.com/goreleaser/goreleaser/internal/pipe/aur"
-	"github.com/goreleaser/goreleaser/internal/pipe/before"
-	"github.com/goreleaser/goreleaser/internal/pipe/brew"
-	"github.com/goreleaser/goreleaser/internal/pipe/build"
-	"github.com/goreleaser/goreleaser/internal/pipe/changelog"
-	"github.com/goreleaser/goreleaser/internal/pipe/checksums"
-	"github.com/goreleaser/goreleaser/internal/pipe/chocolatey"
-	"github.com/goreleaser/goreleaser/internal/pipe/defaults"
-	"github.com/goreleaser/goreleaser/internal/pipe/dist"
-	"github.com/goreleaser/goreleaser/internal/pipe/docker"
-	"github.com/goreleaser/goreleaser/internal/pipe/effectiveconfig"
-	"github.com/goreleaser/goreleaser/internal/pipe/env"
-	"github.com/goreleaser/goreleaser/internal/pipe/git"
-	"github.com/goreleaser/goreleaser/internal/pipe/gomod"
-	"github.com/goreleaser/goreleaser/internal/pipe/krew"
-	"github.com/goreleaser/goreleaser/internal/pipe/metadata"
-	"github.com/goreleaser/goreleaser/internal/pipe/nfpm"
-	"github.com/goreleaser/goreleaser/internal/pipe/nix"
-	"github.com/goreleaser/goreleaser/internal/pipe/notary"
-	"github.com/goreleaser/goreleaser/internal/pipe/partial"
-	"github.com/goreleaser/goreleaser/internal/pipe/prebuild"
-	"github.com/goreleaser/goreleaser/internal/pipe/publish"
-	"github.com/goreleaser/goreleaser/internal/pipe/reportsizes"
-	"github.com/goreleaser/goreleaser/internal/pipe/sbom"
-	"github.com/goreleaser/goreleaser/internal/pipe/scoop"
-	"github.com/goreleaser/goreleaser/internal/pipe/semver"
-	"github.com/goreleaser/goreleaser/internal/pipe/sign"
-	"github.com/goreleaser/goreleaser/internal/pipe/snapcraft"
-	"github.com/goreleaser/goreleaser/internal/pipe/snapshot"
-	"github.com/goreleaser/goreleaser/internal/pipe/sourcearchive"
-	"github.com/goreleaser/goreleaser/internal/pipe/universalbinary"
-	"github.com/goreleaser/goreleaser/internal/pipe/upx"
-	"github.com/goreleaser/goreleaser/internal/pipe/winget"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/announce"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/archive"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/aur"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/before"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/brew"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/build"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/changelog"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/checksums"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/chocolatey"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/defaults"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/dist"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/docker"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/effectiveconfig"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/env"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/git"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/gomod"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/krew"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/metadata"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/nfpm"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/nix"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/notary"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/partial"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/prebuild"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/publish"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/reportsizes"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/sbom"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/scoop"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/semver"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/sign"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/snapcraft"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/snapshot"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/sourcearchive"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/universalbinary"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/upx"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/winget"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 // Piper defines a pipe, which can be part of a pipeline (a series of pipes).
