@@ -1,17 +1,17 @@
 package context
 
 import (
-	"os"
+	"runtime"
 	"testing"
 	"time"
 
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
 func TestNew(t *testing.T) {
-	require.NoError(t, os.Setenv("FOO", "NOT BAR"))
-	require.NoError(t, os.Setenv("BAR", "1"))
+	t.Setenv("FOO", "NOT BAR")
+	t.Setenv("BAR", "1")
 	ctx := New(config.Project{
 		Env: []string{
 			"FOO=BAR",
@@ -20,6 +20,8 @@ func TestNew(t *testing.T) {
 	require.Equal(t, "BAR", ctx.Env["FOO"])
 	require.Equal(t, "1", ctx.Env["BAR"])
 	require.Equal(t, 4, ctx.Parallelism)
+	require.Equal(t, runtime.GOOS, ctx.Runtime.Goos)
+	require.Equal(t, runtime.GOARCH, ctx.Runtime.Goarch)
 }
 
 func TestNewWithTimeout(t *testing.T) {
